==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/news/news.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $Path = str_replace('\\','/', __FILE__);
  $Path = str_replace('news/news.php', '', $Path);
  
  include ($Path."/includes/error_reporting.php");
  include_once ($Path."gigkalender.ini.php");
  include_once ($Path."functions/standard.php");
  include_once ($Path."news/functions.php");
  include_once($Path."includes/frontend_language_selector.php");
  echo '<div class="GigKalender"><div id="News">';
  $EintraegeProSeite = getSetup('SetupNewsEntriesPerPage');
  $AnzahlEintraege = AnzahlVeroeffentlichterNewsInDatenbank();
  if ( $EintraegeProSeite!='0') $AnzahlSeiten = ceil($AnzahlEintraege/$EintraegeProSeite);
  else $AnzahlSeiten = 1;

  if ( $AnzahlEintraege!=0 ) // Einträge vorhanden
  {
    if ( isset($_REQUEST['page']) ) { $aktuelleSeite = $_REQUEST['page']; } 
    else { $aktuelleSeite=$AnzahlSeiten; }
    // wenn Seite aus einem Feed-Reader aufgerufen wird
    if ( isset($_REQUEST['NewsID']) ) 
    {
      $aktuelleSeite = '';
      $NewsID = $_REQUEST['NewsID'];
      $temp = $AnzahlEintraege;
      for ($i=$AnzahlSeiten; $i>=1 AND $aktuelleSeite==''; $i--)
      {
        for ($j=1; $j<=$EintraegeProSeite AND $temp>=1 AND $aktuelleSeite==''; $j++)
        {
          if ($temp==$NewsID) $aktuelleSeite = $i;
          $temp--;
        }
      }
    }
    //
    $obersterEintrag  = ($AnzahlSeiten-$aktuelleSeite)*$EintraegeProSeite;
    //if ($obersterEintrag<0) $obersterEintrag=0;
    // Datensatz-Ausgabe festlegen
      $SQL_Befehl = "SELECT * FROM ".$prefix."news WHERE Publish= 1 order by Date DESC LIMIT ".$obersterEintrag.", ".$EintraegeProSeite;
    // Saemtliche Datensatz-Ausgabe durchfuehren
      $resultat = mysqli_query($db, $SQL_Befehl);
    //if ( $AnzahlSeiten > 1 ) $NewsNavigation = NewsNavigation(); else $NewsNavigation = "";
    if ($AnzahlSeiten>1) echo NewsNavigation('Top');
    $aktuellerEintrag = $AnzahlEintraege-$obersterEintrag;

    while ( $row = mysqli_fetch_array($resultat))
    {
      extract($row);
      if ( $Publish=='1')
      {
        echo '<div id="news'.$aktuellerEintrag.'"><div class="NewsEntry">
                <h2 class="NewsEntryHeadline">
                  <span class="NewsEntryDate">'; 
        echo '['.date($SetupFrontendNewsDateFormat, $Date).']</span> '.$aktuellerEintrag.'. ';
        echo $Title; 
        echo '</h2>
              <div class="NewsEntryText">';
                echo $Text;
        echo '</div></div></div>';
        $aktuellerEintrag--;
      }

    }
    if ($AnzahlSeiten>1) echo NewsNavigation('Bottom');
  }
  else // Keine Einträge vorhanden
  {
    echo '<p>'.$L_167.'</p>';
  }
  echo '</div></div>';
?>

==> downloads.html?file=gigkalender_v1.2.80_040.zip: gigkalender/news/news.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $Path = str_replace('\\','/', __FILE__);
  $Path = str_replace('news/news.php', '', $Path);
  
  include ($Path."/includes/error_reporting.php");
  include_once ($Path."gigkalender.ini.php");
  include_once ($Path."functions/standard.php");
  include_once ($Path."news/functions.php");
  include_once($Path."includes/frontend_language_selector.php");
  echo '<div class="GigKalender"><div id="News">';
  $EintraegeProSeite = getSetup('SetupNewsEntriesPerPage');
  $AnzahlEintraege = AnzahlVeroeffentlichterNewsInDatenbank();
  if ( $EintraegeProSeite!='0') $AnzahlSeiten = ceil($AnzahlEintraege/$EintraegeProSeite);
    else $AnzahlSeiten = 1;
  if ( $AnzahlEintraege!=0 ) // Einträge vorhanden
  {
    if ( isset($_REQUEST['news_page']) ) { $aktuelleSeite = $_REQUEST['news_page']; }
      else { $aktuelleSeite=$AnzahlSeiten; }
    // wenn Seite aus einem Feed-Reader aufgerufen wird
    if ( isset($_REQUEST['NewsID']) ) 
    {
      $aktuelleSeite = '';
      $NewsID = $_REQUEST['NewsID'];
      // v1.2.78_018
      if (is_numeric($NewsID)) {
        if ($NewsID<=$AnzahlEintraege)
          $aktuelleSeite = $AnzahlSeiten-floor(($AnzahlEintraege-$NewsID)/$EintraegeProSeite);
        else {
          echo '<p class="ErrorMessage">ERROR: Unknown News ID! Article got moved or removed.</p>';
          $aktuelleSeite = $AnzahlSeiten; // Bugfix v1.2.78_017
        }
      }
    }
    $obersterEintrag  = ($AnzahlSeiten-$aktuelleSeite)*$EintraegeProSeite;
    // Datensatz-Ausgabe festlegen
      $SQL_Befehl = "SELECT * FROM ".$prefix."news WHERE Publish= 1 order by Date DESC LIMIT ".$obersterEintrag.", ".$EintraegeProSeite;
    // Saemtliche Datensatz-Ausgabe durchfuehren
      $resultat = mysqli_query($db, $SQL_Befehl);
    if ($AnzahlSeiten>1) echo getNewsFrontendNavigation('Top');
    $aktuellerEintrag = $AnzahlEintraege-$obersterEintrag;

    while ( $row = mysqli_fetch_array($resultat))
    {
      extract($row);
      if ( $Publish=='1')
      {
        echo '<div id="news'.$aktuellerEintrag.'"><div class="NewsEntry">
                <h2 class="NewsEntryHeadline">
                  <span class="NewsEntryDate">'; 
        echo '['.date($SetupFrontendNewsDateFormat, $Date).']</span> '.$aktuellerEintrag.'. ';
        echo $Title; 
        echo '</h2>
              <div class="NewsEntryText">';
                echo $Text;
        echo '</div></div></div>';
        $aktuellerEintrag--;
      }
    }
    if ($AnzahlSeiten>1) echo getNewsFrontendNavigation('Bottom');
  }
  else // Keine Einträge vorhanden
  {
    echo '<p>'.$L_167.'</p>';
  }
  echo '</div></div>';
?>
